# patchlevel.sh - maintain the patchlevel of vdr packages
#
# This script is called in debian/rules of the vdr package and all vdr plugins.
#
# In the vdr package it is used to generate the patchlevel file:
#     sh debian/patchlevel.sh make
# to remove it:
#     sh debian/patchlevel.sh clean
# and to set the substitution variable "vdr:Patchlevel":
#     sh debian/patchlevel.sh subst
#
# The vdr plugins read the patchlevel from /usr/include/vdr/patchlevel installed
# by the vdr-dev package and set the substitution variable:
#     sh /usr/share/vdr-dev/patchlevel.sh subst
#
# This substitution variable is used in the debian/control file of the vdr
# package and all vdr plugins:
#     XB-VDR-Patchlevel: ${vdr:Patchlevel}

set -e
case "$*" in
    "make")
        # scan patches in 00list and write to patchlevel file
        echo -n "Patches: "
        for p in $(grep "^[[:space:]]*opt-[0-9][0-9]_" debian/patches/00list | cut -d"_" -f2-); do
            echo -n "$p "
            if [ -z "$PATCHES" ]; then
                PATCHES="$p"
            else
                PATCHES="$PATCHES $p"
            fi
        done
        echo
        echo "vdr:Patchlevel=$PATCHES" > patchlevel
        ;;
    "clean")
        # remove patchlevel file
        rm -f patchlevel
        ;;
    "subst")
        # read patchlevel file and write contents to *.substvars
        if [ -r patchlevel ]; then
            # main vdr package
            PATCHES=$(cat patchlevel)
        else
            # vdr-plugin package
            PATCHES=$(cat /usr/include/vdr/patchlevel)
        fi
        # write *.substvars only if patchlevel not empty
        if [ "$PATCHES" != "vdr:Patchlevel=" ]; then
            # scan control for packages
            for p in $(dh_listpackages); do
                echo "$PATCHES" >> debian/$p.substvars
            done
        fi
        ;;
    *)
        echo >&2 "$0: script expects make|clean|subst as argument"
        exit 1
        ;;
esac
